@@ -7,6 +7,7 @@ import os
 import time
 from uuid import uuid4
 from twisted.internet import reactor
+from twisted.internet.threads import deferToThread
 from twisted.internet.defer import Deferred, DeferredList, maybeDeferred
 from ..aws import AmazonS3, AmazonSDB
 from ..aws import sdb_now
@@ -220,7 +221,8 @@ class BaseServer(object):
             return d
         elif self.functions[function_name]["check_reservation_cache"]:
             kwargs["reservation_cache"] = None
-        d = maybeDeferred(func, **kwargs)
+        d = deferToThread(func, **kwargs)
+        #d = maybeDeferred(func, **kwargs)
         d.addCallback(self._callExposedFunctionCallback, function_name, uuid)
         d.addErrback(self._callExposedFunctionErrback, function_name, uuid)
         return d
