@@ -549,44 +549,24 @@ class ExecutionServer(BaseServer):
         else:
             LOGGER.critical("No average speed to report yet.")
             
-    def executeJobs(self, data=None):
-        for i in range(0, 10):            
-            if len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
-                job = self.job_queue.pop(0)
-                exposed_function = job["exposed_function"]
-                kwargs = job["kwargs"]
-                function_name = job["function_name"]
-                uuid = job["uuid"]
-                del self.queued_jobs[uuid]
-                LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
-                d = self.callExposedFunction(
-                    exposed_function["function"], 
-                    kwargs, 
-                    function_name, 
-                    uuid=uuid,
-                    reservation_fast_cache=job["reservation_cache"])
-                d.addCallback(self._jobCountCallback)
-                d.addErrback(self._jobCountErrback)
-                d.addCallback(self._setNextRequest, uuid, exposed_function["interval"], function_name)
-            else:
-                return
-        reactor.callLater(0.1, self.executeJobs)
-            
-    def _callExposedFunction(
-        self, 
-        func, 
-        interval,
-        kwargs, 
-        function_name, 
-        uuid=None, 
-        reservation_fast_cache=None):
-        d = self.callExposedFunction(
-            func, 
-            kwargs, 
-            function_name, 
-            uuid=uuid,
-            reservation_fast_cache=reservation_fast_cache)
-
+    def executeJobs(self, data=None):           
+        while len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
+            job = self.job_queue.pop(0)
+            exposed_function = job["exposed_function"]
+            kwargs = job["kwargs"]
+            function_name = job["function_name"]
+            uuid = job["uuid"]
+            del self.queued_jobs[uuid]
+            LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
+            d = self.callExposedFunction(
+                exposed_function["function"], 
+                kwargs, 
+                function_name, 
+                uuid=uuid,
+                reservation_fast_cache=job["reservation_cache"])
+            d.addCallback(self._jobCountCallback)
+            d.addErrback(self._jobCountErrback)
+            d.addCallback(self._setNextRequest, uuid, exposed_function["interval"], function_name)
         
     def _jobCountCallback(self, data=None):
         self.job_count += 1
